Skip to contents

Make toast with any bread you want

Usage

make_toast(bread, buttered = FALSE)

Arguments

bread

The type of bread you want to use for your toast

buttered

A boolean value indicating whether you want your toast buttered or not

Value

A string describing the toast you made

Author

Jared Andrews

Examples

make_toast("sourdough", buttered = TRUE)
#> [1] "A buttered slice of sourdough toast"